<?php
/**
 * bizconsulting functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package bizconsulting
 */

if ( ! function_exists( 'bizconsulting_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function bizconsulting_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on bizconsulting, use a find and replace
		 * to change 'bizconsulting' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'bizconsulting', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'menu-1' => esc_html__( 'Primary', 'bizconsulting' ),
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'bizconsulting_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 60,
			'width'       => 400,
			'flex-width'  => true,
			'flex-height' => true,
		) );
	}
endif;
add_action( 'after_setup_theme', 'bizconsulting_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function bizconsulting_content_width() {
	// This variable is intended to be overruled from themes.
	// Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
	// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
	$GLOBALS['content_width'] = apply_filters( 'bizconsulting_content_width', 640 );
}
add_action( 'after_setup_theme', 'bizconsulting_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function bizconsulting_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'bizconsulting' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'bizconsulting' ),
		'before_widget' => '<section id="%1$s" class="left-blog-page %2$s"><div class="left-blog">',
		'after_widget'  => '</div></section>',
		'before_title'  => '<h4 class="widget-title">',
		'after_title'   => '</h4>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Front Page Slider', 'bizconsulting' ),
		'id'            => 'sidebar-2',
		'description'   => esc_html__( 'Add widgets here.', 'bizconsulting' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Front Page Right Sidebar', 'bizconsulting' ),
		'id'            => 'sidebar-3',
		'description'   => esc_html__( 'Add widgets here.', 'bizconsulting' ),
		'before_widget' => '<section id="%1$s" class="left-blog-page %2$s"><div class="left-blog">',
		'after_widget'  => '</div></section>',
		'before_title'  => '<h4 class="widget-title">',
		'after_title'   => '</h4>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Page Right Sidebar', 'bizconsulting' ),
		'id'            => 'sidebar-4',
		'description'   => esc_html__( 'Add widgets here.', 'bizconsulting' ),
		'before_widget' => '<section id="%1$s" class="left-blog-page %2$s"><div class="left-blog">',
		'after_widget'  => '</div></section>',
		'before_title'  => '<h4 class="widget-title">',
		'after_title'   => '</h4>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Footer Sidebar', 'bizconsulting' ),
		'id'            => 'sidebar-5',
		'description'   => esc_html__( 'Add widgets here.', 'bizconsulting' ),
		'before_widget' => '<section id="%1$s" class="col-md-4 col-sm-5 col-xs-12 footer-widget %2$s"><div class="footer-content"><div class="footer-head">',
		'after_widget'  => '</div></div></section>',
		'before_title'  => '<h4 class="widget-title">',
		'after_title'   => '</h4>',
	) );
}
add_action( 'widgets_init', 'bizconsulting_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
require get_template_directory() . '/inc/bizconsulting_scripts.php';

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Implement custom-comments.
 */
require get_template_directory() . '/inc/custom-comments.php';

/**
 * Implement Register Custom Navigation Walker.
 */
require get_template_directory() . '/vendors/wp-bootstrap-navwalker/wp-bootstrap-navwalker.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/vendors/bpt-customizer/class-customize.php';


/* Calling in the admin area for the Welcome Page */
if ( is_admin() ) {
	require get_template_directory() . '/vendors/pro/bpt-admin-page.php';
}